==> agconnect_auth-1.2.0%2B300.tar.gz: lib/src/agconnect_auth.dart <==
/*
    Copyright 2020-2021. Huawei Technologies Co., Ltd. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

import 'dart:async';

import 'package:agconnect_auth/agconnect_auth.dart';
import 'package:agconnect_auth/src/platform_auth.dart';
import 'package:flutter/services.dart';

class AGCAuth {
  final MethodChannel _channel = PlatformAuth.methodChannel;
  final Stream<dynamic> _tokenListener =
      PlatformAuth.eventChannel.receiveBroadcastStream();

  /// 获取AGCAuth实例
  static final AGCAuth instance = AGCAuth();

  Future<SignInResult> signIn(AGCAuthCredential credential) {
    assert(credential != null);
    return _channel
        .invokeMethod(
            'signIn', <String, dynamic>{'credential': credential.toMap()})
        .then((value) => SignInResult.fromMap(value))
        .catchError(PlatformAuth.handlePlatformException);
  }

  Future<SignInResult> signInAnonymously() {
    return _channel
        .invokeMethod('signInAnonymously')
        .then((value) => SignInResult.fromMap(value))
        .catchError(PlatformAuth.handlePlatformException);
  }

  Future<void> signOut() {
    return _channel
        .invokeMethod('signOut')
        .catchError(PlatformAuth.handlePlatformException);
  }

  Future<void> deleteUser() {
    return _channel
        .invokeMethod('deleteUser')
        .catchError(PlatformAuth.handlePlatformException);
  }

  Future<AGCUser> get currentUser {
    return _channel
        .invokeMethod('getCurrentUser')
        .then((value) => value != null ? AGCUser.fromMap(value) : null)
        .catchError(PlatformAuth.handlePlatformException);
  }

  Stream<TokenSnapshot> tokenChanges() {
    return _tokenListener.map((event) => TokenSnapshot.fromMap(event));
  }

  Future<SignInResult> createEmailUser(EmailUser user) {
    assert(user != null);
    return _channel
        .invokeMethod('createUserWithEmail', <String, dynamic>{
          'email': user.email,
          'password': user.password,
          'verifyCode': user.verifyCode
        })
        .then((value) => SignInResult.fromMap(value))
        .catchError(PlatformAuth.handlePlatformException);
  }

  Future<SignInResult> createPhoneUser(PhoneUser user) {
    assert(user != null);
    return _channel
        .invokeMethod('createUserWithPhone', <String, dynamic>{
          'countryCode': user.countryCode,
          'phoneNumber': user.phoneNumber,
          'password': user.password,
          'verifyCode': user.verifyCode
        })
        .then((value) => SignInResult.fromMap(value))
        .catchError(PlatformAuth.handlePlatformException);
  }

  Future<void> resetPasswordWithEmail(
      String email, String newPassword, String verifyCode) {
    assert(email != null);
    assert(newPassword != null);
    assert(verifyCode != null);
    return _channel.invokeMethod('resetPasswordWithEmail', <String, dynamic>{
      'email': email,
      'password': newPassword,
      'verifyCode': verifyCode
    }).catchError(PlatformAuth.handlePlatformException);
  }

  Future<void> resetPasswordWithPhone(String countryCode, String phoneNumber,
      String newPassword, String verifyCode) {
    assert(countryCode != null);
    assert(phoneNumber != null);
    assert(newPassword != null);
    assert(verifyCode != null);
    return _channel.invokeMethod('resetPasswordWithPhone', <String, dynamic>{
      'countryCode': countryCode,
      'phoneNumber': phoneNumber,
      'password': newPassword,
      'verifyCode': verifyCode
    }).catchError(PlatformAuth.handlePlatformException);
  }
}

==> agconnect_auth-1.5.0%2B300.tar.gz: lib/src/agconnect_auth.dart <==
/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2021. All rights reserved.
 */

import 'dart:async';

import 'package:agconnect_auth/agconnect_auth.dart';
import 'package:agconnect_auth/src/platform_auth.dart';
import 'package:flutter/services.dart';

class AGCAuth {
  final MethodChannel _channel = PlatformAuth.methodChannel;
  final Stream<dynamic> _tokenListener =
      PlatformAuth.eventChannel.receiveBroadcastStream();

  /// 获取AGCAuth实例
  static final AGCAuth instance = AGCAuth();

  Future<SignInResult> signIn(AGCAuthCredential credential) {
    return _channel
        .invokeMethod(
            'signIn', <String, dynamic>{'credential': credential.toMap()})
        .then((value) => SignInResult.fromMap(value))
        .catchError(PlatformAuth.handlePlatformException);
  }

  Future<SignInResult> signInAnonymously() {
    return _channel
        .invokeMethod('signInAnonymously')
        .then((value) => SignInResult.fromMap(value))
        .catchError(PlatformAuth.handlePlatformException);
  }

  Future<void> signOut() {
    return _channel
        .invokeMethod('signOut')
        .catchError(PlatformAuth.handlePlatformException);
  }

  Future<void> deleteUser() {
    return _channel
        .invokeMethod('deleteUser')
        .catchError(PlatformAuth.handlePlatformException);
  }

  Future<AGCUser?> get currentUser {
    return _channel
        .invokeMethod('getCurrentUser')
        .then((value) => value != null ? AGCUser.fromMap(value) : null)
        .catchError(PlatformAuth.handlePlatformException);
  }

  Stream<TokenSnapshot> tokenChanges() {
    return _tokenListener.map((event) => TokenSnapshot.fromMap(event));
  }

  Future<SignInResult> createEmailUser(EmailUser user) {
    return _channel
        .invokeMethod('createUserWithEmail', <String, dynamic>{
          'email': user.email,
          'password': user.password,
          'verifyCode': user.verifyCode
        })
        .then((value) => SignInResult.fromMap(value))
        .catchError(PlatformAuth.handlePlatformException);
  }

  Future<SignInResult> createPhoneUser(PhoneUser user) {
    return _channel
        .invokeMethod('createUserWithPhone', <String, dynamic>{
          'countryCode': user.countryCode,
          'phoneNumber': user.phoneNumber,
          'password': user.password,
          'verifyCode': user.verifyCode
        })
        .then((value) => SignInResult.fromMap(value))
        .catchError(PlatformAuth.handlePlatformException);
  }

  Future<void> resetPasswordWithEmail(
      String email, String newPassword, String verifyCode) {
    return _channel.invokeMethod('resetPasswordWithEmail', <String, dynamic>{
      'email': email,
      'password': newPassword,
      'verifyCode': verifyCode
    }).catchError(PlatformAuth.handlePlatformException);
  }

  Future<void> resetPasswordWithPhone(String countryCode, String phoneNumber,
      String newPassword, String verifyCode) {
    return _channel.invokeMethod('resetPasswordWithPhone', <String, dynamic>{
      'countryCode': countryCode,
      'phoneNumber': phoneNumber,
      'password': newPassword,
      'verifyCode': verifyCode
    }).catchError(PlatformAuth.handlePlatformException);
  }
}
